/*
	"3d.c" - Sample Code

	Copyright (C) 1998  Sony Computer Entertainment Europe
	All rights Reserved
*/

	// All TMD/HMD functions, including rendering and animation.

#define SOURCE_3D_C
//#define DEBUG

#include <sys/types.h>
#include <libetc.h>
#include <libgte.h>
#include <libgpu.h>
#include <libgs.h>
#include <libhmd.h>
#include <stdio.h>
#include <rand.h>

#include "pad.h"
#include "3d.h"
#include "water.h"
#include "main.h"
#include "display.h"
#include "music/xmplayer.h"

#include "common/scan.h"

	// For a 512x256 screen, this is the aspect ratio that we use in the
	// rotation matrix.

#define ASPECT_RATIO (2/3)
#define ASPECT_RATIO_INT (0xaaaa)  // 2/3 in 1,15,16 format

// The back off distance is how far away from the center of the environment
// the dinosaur is. It is the distance that the dinosaur moves away from the pond
// at the beginning of the demo - so basically, it is defined by the ending position
// of the back off animation.

#define BACK_OFF_DISTANCE 3229
	// The circumference of the circle, at the radius the dinosaur is at.
#define BACK_OFF_CIRCUMFERENCE 20288

#ifdef DEVKIT
#define MESSAGES_ON
#endif

	// The animation of the dinosaur is fairly simple. There are a number
	// of different 'states' the dinosaur can be in, and although the
	// user may want it to be in one state ("Walking Forwards"), the dino
	// will have to travel through more than one state to smoothly
	// reach the desired state.

#ifdef MESSAGES_ON
char *stateStrings[] = {	// Used for debugging
	"STOPPED",
	"STOP_TO_WALK1",
	"WALK1_TO_STOP",
	"WALK2_TO_STOP",
	"WALK1_TO_WALK2",
	"WALK2_TO_WALK1",
	"STOP_TO_BACKWALK1",
	"BACKWALK1_TO_STOP",
	"BACKWALK2_TO_STOP",
	"BACKWALK1_TO_BACKWALK2",
	"BACKWALK2_TO_BACKWALK1",
	"STOMP",
	"BORED"
	 };
#endif

extern char
	ENVIRO_RAW[],
	WLK_FORE_RAW[],
	WALKBACK_RAW[];

static VOLCANO_STATUS VolcanoStatus = OFF;
static int
	animFrameIndex = 0,	// The current animation number.
	animFrameCount = 0;	// The number of frames remaining in the current animation.
static AnimFileHeader *animDataArea = (AnimFileHeader *)WLK_FORE_RAW;

static int animIndices[][4] = { // Start frame, number of frames, animation file to look at, Z translation
	{ 0,  1, 0, 0},		// STOPPED

	{ 2, 30, 0, -1},	// STOP to WALK1
	{92, 26, 0, -562},	// WALK1 to STOP
	{122, 24, 0, -547},	// WALK2 to STOP
	{32, 30, 0, -59},	// WALK1 to WALK2
	{62, 30, 0, -312},	// WALK2 to walk1

	{ 2, 30, 1, 4},		// STOP to BWALK1
	{92, 26, 1, 585},	// BWALK1 to STOP
	{122, 24, 1, 383},	// BWALK2 to STOP
	{32, 30, 1, 163},	// BWALK1 to BWALK2
	{62, 30, 1, 392},	// BWALK2 to BWALK1

	{152, 29, 1, 421},	// STOMP
	{180, 29, 1, 421}	// BORED
};

// =======================================================================

		// The rotation of the camera, and the rotation of the camera
		// in the 'reflection' position.

		// The information below is copied directly over the HMD file
		// in memory to create a texture animation (the volcano erupting).
		// It is simple to find the address where it should be copied (see
		// below).

static u_char VolcanoAnim[][16] = {
	{ 32,164, 0xf0,0x79,		// u0, v0, clut
	  63,164, 0x9e,0x00,		// u1,v1, tpage
	  32,227, 10,0,				// u2,v2, vert0
	  63,227,  7,0 },			// u3,v4, vert1
	{ 64,164, 0xf0,0x7b,
	  95,164, 0x9e,0x00,
	  64,227, 10,0,
	  95,227,  7,0 },
	{ 96,164, 0x30,0x7a,
	 127,164, 0x9e,0x00,
	  96,227, 10,0,
	 127,227,  7,0},
	{  0,164, 0x30,0x7c,
	  31,164, 0x9f,0x00,
	   0,227, 10,0,
	  31,227,  7,0 },
	{ 32,164, 0x70,0x7a,
	  63,164, 0x9f,0x00,
	  32,227, 10,0,
	  63,227,  7,0 },
	{ 64,164, 0x70,0x7c,
	  95,164, 0x9f,0x00,
	  64,227, 10,0,
	  95,227,  7,0 },
	{ 96,164, 0xb0,0x7a,
	 127,164, 0x9f,0x00,
	  96,227,  10,0,
	 127,227,  7,0 }
	};

// ======================================================================

	// This function animates the volcano depending on the volcano's
	// eruption status.

static void animateVolcano(VOLCANO_STATUS status) {
	static int
		frameDec = 1,
		animFrame = -1;
	int copyFrame;

		// This will contain the address of the u_long following the primitive Header.
	u_long *VolcanoPrimAddress;
		// This will contain the address of the item pointed to by the pointer at
		// the above address. (got that :O) ? )
		// It is the address we want to copy the animation data to.
	char *VolcanoPrim;

	if(introModeOn) {
		VolcanoPrimAddress = environmentHMD.modelAddress + environmentHMD.numPrimBlocks + 4;
		VolcanoPrim = (char *)environmentHMD.modelAddress+ (u_long)*VolcanoPrimAddress;
	} else {
		VolcanoPrimAddress = environmentNPHMD.modelAddress + environmentNPHMD.numPrimBlocks + 4;
		VolcanoPrim = (char *)environmentNPHMD.modelAddress+ (u_long)*VolcanoPrimAddress;
	}

	if(status == OFF) {
		copyFrame = 0;
	} else {
		if(frameDec-- == 0) {
			frameDec = 15;
			animFrame++;
			if(animFrame == 7) {
				animFrame = 1;
			}
		}
		copyFrame = animFrame;
	}
	memcpy(VolcanoPrim, VolcanoAnim[copyFrame],16);
}

// ======================================================================

	// This function will animate the volcano if necessary, activate the
	// Dual Shock, adjust the sound level and shake the screen, dependent on
	// the current state of the volcano. Once the shaking has died down, it
	// chooses an arbitrary and random length of time to wait until shaking
	// again.

void processVolcano(void) {

	static int
		VolcanoTimer = 1400,	// Time before eruption
		VolcanoSoundTimer = 0;
	int CameraShudderIntensity = 0;

	if(VolcanoTimer > 0) {
		VolcanoTimer--;
	} else {
		switch(VolcanoStatus) {
			case OFF:
				VolcanoSoundTimer = 255;
				doEruptionSound(VOLUME_UP);
				VolcanoStatus = VOLUME_UP;
				break;

			case VOLUME_UP:
				VolcanoSoundTimer--;
				CameraShudderIntensity = 255 - VolcanoSoundTimer;
				VolcanoDualShockIntensity = 50 + (255 - VolcanoSoundTimer) * (95-50) / 255;
				if(VolcanoDualShockIntensity < 0) {
					VolcanoDualShockIntensity = 0;
				}
				if(VolcanoSoundTimer == 0) {
					VolcanoStatus = RUMBLING;
					VolcanoSoundTimer = 400;
				}
				break;

			case RUMBLING:
				CameraShudderIntensity = 255;
				VolcanoDualShockIntensity = 95;
				VolcanoSoundTimer--;
				if(VolcanoSoundTimer == 0) {
					VolcanoStatus = VOLUME_DOWN;
					doEruptionSound(VOLUME_DN);
					VolcanoSoundTimer = 256;
				}
				break;

			case VOLUME_DOWN:
				VolcanoSoundTimer--;
				CameraShudderIntensity = VolcanoSoundTimer;
				VolcanoDualShockIntensity = VolcanoSoundTimer * 95 / 255;
				if(VolcanoDualShockIntensity < 0) {
					VolcanoDualShockIntensity = 0;
				}
				if(VolcanoSoundTimer == 0) {
					VolcanoStatus = OFF;
					VolcanoTimer = 2000 + (rand() & 7) * 200;
				}
				break;
			}
	}

	// Shake the camera - CameraShudder_LR is the Left/Right shake value,
	// CameraShudder_UD is the Up/Down shake value.

	if(VolcanoStatus == OFF || (CameraShudderIntensity < 50)) {
		CameraShudder_LR = 0;
		CameraShudder_UD = 0;
	} else {
		CameraShudder_LR = (rand() % CameraShudderIntensity/10) - 10;
		CameraShudder_UD = (rand() % CameraShudderIntensity/10) - 10;
	}
		// Animate the volcano texture
	animateVolcano(VolcanoStatus);
}

// ======================================================================

	// At the beginning of the demo, the dinosaurs shadow 'pops' in, which
	// looks bad - to get around this, we display it with 0 RGB, then fade
	// it up to its proper value (40) after a short time. It's not much better,
	// but it is better.

void fadeInShadow(void) {
	static int fadeFrameRate = 0;
	static int fadeWait = 270;
	static u_char fadeValue = 0;
	u_long *ShadowPrimAddress;
	char *ShadowPrim;

	if(fadeWait > 0) {	// Wait a few frames before fading in the shadow.
		fadeWait--;
	} else {
		if(fadeFrameRate == 0) {
			fadeFrameRate = 2;
			if(fadeValue < 40) {
				fadeValue++;

				ShadowPrimAddress = triceratopsHMD.modelAddress + triceratopsHMD.numPrimBlocks + 4;
				ShadowPrim = (char *)triceratopsHMD.modelAddress+ (u_long)*ShadowPrimAddress;

				ShadowPrim[0] = fadeValue;
				ShadowPrim[1] = fadeValue;
				ShadowPrim[2] = fadeValue;
			}
		} else {
			fadeFrameRate--;
		}
	}
}

// ======================================================================

	// This function creates the matrix that transforms from world
	// coordinates to screen coordinates.


void createWorldToScreenMatrix(GsRVIEW2 *view, CAMERA_MODE mode) {
	extern MATRIX GsWSMATRIX;
	VECTOR t,tmp;

	switch(mode) {
		case NORMAL_CAMERA:
			RotMatrix_gte(&CameraRotate,&GsWSMATRIX);
			tmp.vx = -view->vpx;
			tmp.vy = -view->vpy;
			tmp.vz = -view->vpz;
			GsSetProjection(PROJECTION_DISTANCE);
			break;

		case REFLECTION_CAMERA:
			RotMatrix_gte(&ReflectionCamera,&GsWSMATRIX);
			tmp.vx = -view->vpx;
			if(introModeOn) {
				tmp.vy = -1250;
			} else {
				tmp.vy = -view->vpy;
			}
			tmp.vz = -view->vpz;
			if(introModeOn) {
				GsSetProjection(170);
			} else {
				GsSetProjection(PROJECTION_DISTANCE);
			}
			break;
	}

	GsWSMATRIX.t[0] = GsWSMATRIX.t[1] = GsWSMATRIX.t[2] = 0;

	ApplyMatrixLV(&GsWSMATRIX, &tmp, (VECTOR *)&t);
	GsWSMATRIX.t[0] = (short)t.vx;
	GsWSMATRIX.t[1] = (short)t.vy;
	GsWSMATRIX.t[2] = (short)t.vz;

	if(mode == 0 || (mode != 0 && !introModeOn)) {
		GsWSMATRIX.m[1][0] = ((int)GsWSMATRIX.m[1][0] * ASPECT_RATIO_INT) / 0x10000;
		GsWSMATRIX.m[1][1] = ((int)GsWSMATRIX.m[1][1] * ASPECT_RATIO_INT) / 0x10000;
		GsWSMATRIX.m[1][2] = ((int)GsWSMATRIX.m[1][2] * ASPECT_RATIO_INT) / 0x10000;
	} else {
		GsWSMATRIX.m[1][0] = ((int)GsWSMATRIX.m[1][0] * 62540) / 0x10000;
		GsWSMATRIX.m[1][1] = ((int)GsWSMATRIX.m[1][1] * 62540) / 0x10000;
		GsWSMATRIX.m[1][2] = ((int)GsWSMATRIX.m[1][2] * 62540) / 0x10000;
	}
}

// =======================================================================
	// Standard initialisation of a TMD.

void initialiseTMD(u_long *tmd, char objNum, TMD_ObjectHandler *oh) {
	oh->modelAddress = tmd;
	oh->whichModel = objNum;

	oh->position.vx = 0;
	oh->position.vy = 0;
	oh->position.vz = 0;

	oh->rotate.vx = 0;
	oh->rotate.vy = 0;
	oh->rotate.vz = 0;

	oh->handler.coord2 = &(oh->coord);
	GsInitCoordinate2(WORLD, &(oh->coord));

	GsMapModelingData(tmd+1);
	GsLinkObject4((u_long)(tmd+3), &oh->handler, objNum);
}


// =======================================================================

void initialise3D(void) {

		// Initialise view
	TopView.vrx =
	TopView.vry =
	TopView.vrz = 0;

	TopView.vpx = 0;
	TopView.vpy = 0;
	TopView.vpz = -1000;

	TopView.rz  = 0;
	TopView.super = WORLD;

	//--set perspective
	GsSetProjection(PROJECTION_DISTANCE);

	VolcanoDualShockIntensity = 0;
}

// ===================================================================

void DrawTMDModel(TMD_ObjectHandler *p, GsOT *ot, int OT_Len) {
	static MATRIX coordMatrix;

		//--rotate the object
	RotMatrix_gte(&p->rotate, &p->coord.coord); // Get object rotation matrix
	p->coord.coord.t[0] = p->position.vx; // Set translation
	p->coord.coord.t[1] = p->position.vy;
	p->coord.coord.t[2] = p->position.vz;
	p->coord.flg = 0;                       // Flag to GTE says it's adjusted

	GsGetLs(&p->coord, &coordMatrix); // Translate to screen
	GsSetLsMatrix(&coordMatrix);              // Set up GTE

	GsSortObject4(&p->handler,
				  ot,
				  14-OT_Len,
				  getScratchAddr(0));
}

// =======================================================================
// ==== H M D  F U N C T I O N S =========================================
// =======================================================================

	// Generic HMD initialisation code. This is basically the same
	// as the sample HMD initialisation code.

	// I have my own 'handler' structure, which includes a dummy coordinate
	// system. This allows me to rotate the root node after translation.


void initialiseHMD(u_long *hmdObject, HMD_ObjectHandler *oh) {

	int numPrimBlocks;
	u_long *hmd = hmdObject;
	int	i,j;
	int numCoords;
	GsTYPEUNIT ut;
	bool INI_bitFound = FALSE;

	debugStr(("#### Initialising HMD ####"));

	GsMapUnit(hmd);

	debugStr(("Mapping complete."));

	hmd += 3; // Skips ID, flag and Primitive Header pointer
	numPrimBlocks = oh->numPrimBlocks = *hmd;
	debugStr(("This HMD file contains %d Primitive Blocks\n", numPrimBlocks));
	hmd++;

	oh->modelAddress = hmdObject;
	setVector(&oh->position,0,0,0);
	setVector(&oh->rotate,0,0,0);
	oh->root.flg = 0;
	oh->root.super = WORLD;
	oh->root.matrix = GsIDMATRIX;
	setVector(&oh->root.rot,0,0,0);

	for (i = 0; i < numPrimBlocks; i++) {
		oh->primBlocks[i].coord = NULL;
		oh->primBlocks[i].primtop = (u_long *)hmd[i];
		if(oh->primBlocks[i].primtop == NULL)
			continue;

			// Prepare GsScanUnit for enumeration over Primitive Block
		debugStr(("Scanning Prim Block %3d : ",i));
		GsScanUnit(oh->primBlocks[i].primtop, 0, 0, 0);
		while(GsScanUnit(0, &ut, &mainOT[0], getScratchAddr(0))) {
			if (((ut.type >> 24 == 0x00)	// CTG 0: POLY
			|| (ut.type >> 24 == 0x01)	// CTG 1: SHARED
			|| (ut.type >> 24 == 0x05)	// CTG 5: GROUND
			|| (ut.type >> 24 == 0x06)	// CTG 6: ENVMAP(beta)
			) && (ut.type & 0x00800000)) {	// check INI bit
				if(INI_bitFound == TRUE) {
					printf("INI bit detected twice! Should only occur once per HMD model\n.");
					exit(1);
				}
				debugStr(("INI bit detected: Mapping coordinate systems.\n"));

				INI_bitFound = TRUE;
				oh->coordinates = GsMapCoordUnit(hmdObject, ut.ptr);
					// clear INI bit
				ut.type &= (~0x00800000);
				numCoords = *((u_long *)oh->coordinates - 1);
				for(j = 0; j < numCoords; j++) {
					if(oh->coordinates[j].super == WORLD) {
						oh->coordinates[j].super = &oh->root;
						debugStr(("Remapped WORLD to our root"));
					}
				}
			}
			*ut.ptr = NULL;
			debugStr(("type = %08x : ",ut.type));
			switch (ut.type >> 24) {
				case 0x00:	// CTG 0: POLY or NULL
					*ut.ptr = scan_poly(ut.type);
					break;
				case 0x01:	// CTG 1: SHARED
					*ut.ptr = scan_shared(ut.type);
					break;
				case 0x02:	// CTG 2: IMAGE
					*ut.ptr = scan_image(ut.type);
					((GsUNIT_Funcp)(*ut.ptr))
						((GsARGUNIT *)getScratchAddr(0));
					*ut.ptr = (u_long)GsU_00000000;
					break;
				case 0x03:	// CTG 3: ANIMATION
					*ut.ptr = scan_anim(ut.type);
					if (*ut.ptr != NULL
					&& *ut.ptr != (u_long)GsU_00000000) {
						oh->numAnims = GsLinkAnim(&oh->sequence, ut.ptr);
						if (GsScanAnim(ut.ptr, 0) == 0) {
							printf("ScanAnim failed!!\n\n");
						} else {
							scan_interp();
						}
					}
					break;
				case 0x04:	// CTG 4: MIMe
					*ut.ptr = scan_mime(ut.type);
					switch (ut.type) {
					case GsVtxMIMe:
					case GsNrmMIMe:
					case GsJntAxesMIMe:
					case GsJntRPYMIMe:
						break;
					case GsRstVtxMIMe:
						GsInitRstVtxMIMe(
							ut.ptr, GsGetHeadpUnit());
						break;
					case GsRstNrmMIMe:
						GsInitRstNrmMIMe(
							ut.ptr, GsGetHeadpUnit());
						break;
					default:
					}
					break;
				case 0x05:	// CTG 5: GROUND
					*ut.ptr = scan_gnd(ut.type);
					break;
				case 0x06:	// CTG 6: ENVMAP(beta)
					*ut.ptr = scan_envmap(ut.type);
					break;
				default:
			}
			if (*ut.ptr == NULL) {
				printf("unsupported type 0x%08x\n", (int)ut.type);
				*ut.ptr = (u_long)GsU_00000000;
			}
		}	// End while
		oh->primBlocks[i].coord = NULL;
	}

	if (oh->coordinates != NULL) {
		debugStr(("Linking coordinates to HMD handler"));
		for(i = 1; i < numPrimBlocks - 1; i++) {
			oh->primBlocks[i].coord = &oh->coordinates[i-1];
			oh->translations[i].vx = oh->coordinates[i-1].matrix.t[0];
			oh->translations[i].vy = oh->coordinates[i-1].matrix.t[1];
			oh->translations[i].vz = oh->coordinates[i-1].matrix.t[2];
		}
	}
}

// ======================================================================

	// This function initialises an animation for the dinosaur. One of
	// the animations (the 'backoff' animation) needs to be stretched,
	// so the purpose of the second argument is to specify whether the passed
	// animation needs to be stretched.

void initAnimateHMD(char *animation, bool adjustBackOffFlag){
	AnimFileHeader *an = (AnimFileHeader *)animation;
	int i;

	an->Rotation = (SVECTOR *)( (u_long)an->Rotation + (u_long)animation);
	an->Translation = (SVECTOR *)( (u_long)an->Translation + (u_long)animation);

		// Here we are stretching the back off animation's root node
		// translation, because Alias exported it too small and for
		// reasons that will be forever lost in the mists of time, we can't
		// scale it in Alias without the dinosaur model looking like
		// an explosion in a polygon factory. So we hack it back to normal here.
	if(adjustBackOffFlag) {
		for(i = 0; i < an->NumFrames; i++) {
			an->Translation[i].vz = (an->Translation[i].vz -1508) * 2.4 + 1050;
		}
	}

}

// ======================================================================

	// This function inserts the current animation's frame into the
	// dinosaur's coordinate system. If the 'advance' parameter is
	// true, the frame number is increased, but the animation is not
	// reinserted.

void AnimateHMD(HMD_ObjectHandler *hmd, char *animation, bool advance) {
	static int frameNum = 0;
	int i,j;
	SVECTOR *rotation;
	AnimFileHeader *an = (AnimFileHeader *)animation;
	GsUNIT *op = hmd->primBlocks;

	if(!advance) {
		rotation = &an->Rotation[frameNum * an->NumJoints];

		hmd->position.vx = an->Translation[frameNum].vx;
		hmd->position.vy = an->Translation[frameNum].vy;
		hmd->position.vz = an->Translation[frameNum].vz;

		op++;
		for(i = 0,j=0; i < an->NumJoints; i++, op++,rotation++) {
			op->coord->flg = 0;
			op->coord->rot.vx = rotation->vx;
			op->coord->rot.vy = rotation->vy;
			op->coord->rot.vz = rotation->vz;
		}
#ifdef MESSAGES_ON
		FntPrint("Frame: %d\n",frameNum);
#endif
	} else {

		frameNum++;
		if(frameNum >= an->NumFrames) {
			frameNum = 0;
		}
	}
}

// ======================================================================

	// Given a current animation state and a desired animation state, this
	// function returns the next state to follow the current state, which
	// draws ever closer to the desired state.

	// The walkFlag parameter specifies whether the user is holding down
	// the 'walk forwards/backwards' key.

WALKSTATE AnimNextState(WALKSTATE current, WALKSTATE desired, bool walkFlag) {
	switch(current) {
		case STOPPED:
			switch(desired) {
				case STOPPED:
					return STOPPED;
				case WALK1_TO_WALK2:
				case WALK2_TO_WALK1:
				case STOP_TO_WALK1:
				case WALK1_TO_STOP:
				case WALK2_TO_STOP:
					return STOP_TO_WALK1;
				case BACKWALK1_TO_BACKWALK2:
				case BACKWALK2_TO_BACKWALK1:
				case STOP_TO_BACKWALK1:
				case BACKWALK1_TO_STOP:
				case BACKWALK2_TO_STOP:
					return STOP_TO_BACKWALK1;
				case STOMP:
					return STOMP;
				case BORED:
					return BORED;
			}

		case STOP_TO_WALK1:
			if(walkFlag) {
				return WALK1_TO_WALK2;
			}
			switch(desired) {
				case WALK1_TO_WALK2:
				case WALK2_TO_WALK1:
				case WALK2_TO_STOP:
					return WALK1_TO_WALK2;
				default:
					return WALK1_TO_STOP;
			}

		case WALK1_TO_STOP:
		case WALK2_TO_STOP:
		case BACKWALK1_TO_STOP:
		case BACKWALK2_TO_STOP:
			return AnimNextState(STOPPED,desired,walkFlag);

		case STOP_TO_BACKWALK1:
			if(walkFlag) {
				return BACKWALK1_TO_BACKWALK2;
			}
			switch(desired) {
				case BACKWALK1_TO_BACKWALK2:
				case BACKWALK2_TO_BACKWALK1:
				case BACKWALK2_TO_STOP:
					return BACKWALK1_TO_BACKWALK2;
				default:
					return BACKWALK1_TO_STOP;
			}

		case BACKWALK1_TO_BACKWALK2:
			if(walkFlag) {
				if(desired == WALK1_TO_WALK2) {
					return BACKWALK2_TO_STOP;
				} else {
					return BACKWALK2_TO_BACKWALK1;
				}
			} else {
				return BACKWALK2_TO_STOP;
			}

		case WALK1_TO_WALK2:
			if(walkFlag) {
				if(desired == BACKWALK1_TO_BACKWALK2) {
					return WALK2_TO_STOP;
				} else {
					return WALK2_TO_WALK1;
				}
			} else {
				return WALK2_TO_STOP;
			}

		case BACKWALK2_TO_BACKWALK1:
			if(walkFlag) {
				if(desired == WALK1_TO_WALK2) {
					return BACKWALK1_TO_STOP;
				} else {
					return BACKWALK1_TO_BACKWALK2;
				}
			} else {
				return BACKWALK1_TO_STOP;
			}

		case WALK2_TO_WALK1:
			if(walkFlag) {
				if(desired == BACKWALK1_TO_BACKWALK2) {
					return WALK1_TO_STOP;
				} else {
					return WALK1_TO_WALK2;
				}
			} else {
				return WALK1_TO_STOP;
			}

		case STOMP:
			if(desired == STOMP) {
				return STOMP;
			} else {
				return AnimNextState(STOPPED,desired,walkFlag);
			}

		case BORED:
			if(desired == BORED) {
				return BORED;
			} else {
				return AnimNextState(STOPPED,desired,walkFlag);
			}
	}
	return STOPPED;
}

// ==================================================================

	// This function processes the triceratops animation, and moves the
	// triceratops around the clearing.

	// The animations of the dinosaur do not have the root node centred
	// at 0, the root node translation moves over time. Thus,
	// the current position is determined from combining the last
	// known position at an animation state change with the Z offset
	// in the animation's translation.

void WalkTriceratops(bool walkFlag) {
	int i;
	SVECTOR *rotation;
	AnimFileHeader *anFore = (AnimFileHeader *)WLK_FORE_RAW;
	AnimFileHeader *anBack = (AnimFileHeader *)WALKBACK_RAW;
	GsUNIT *op = triceratopsHMD.primBlocks;
	static int
		linearPosition = 0,
		lastStatePosition = BACK_OFF_CIRCUMFERENCE - 200,
		lastZTranslation = 0,
		CameraShudderFrame = 0;

	if(animFrameCount <= 0) {	// If we have reached a state change...

			// Get the new state.
		currentState = AnimNextState(currentState, desiredState, walkFlag);
		if(currentState == BORED) {
			desiredState = STOPPED;
		}
		animFrameIndex = animIndices[currentState][0];
		animFrameCount = animIndices[currentState][1];
		animDataArea = (animIndices[currentState][2] == 0) ? anFore : anBack;
		lastStatePosition += lastZTranslation;
		if(lastStatePosition < 0) {
			lastStatePosition = (BACK_OFF_CIRCUMFERENCE) - lastStatePosition;
		}
	}
#ifdef MESSAGES_ON
		// Displays the Current anim state, the desired anim state, and the walkFlag value.
	FntPrint("C: %s  D: %s  W: %d\n",stateStrings[currentState],stateStrings[desiredState],walkFlag);
#endif

	lastZTranslation = animDataArea->Translation[animFrameIndex].vz - animIndices[currentState][3];

	linearPosition = lastStatePosition + lastZTranslation;

	// BACK_OFF_DISTANCE * 2 * PI is the circumference of the circle that
	// the dino walks in. Linear position is the distance the dino has moved
	// around this. We need to work out the angle (from 0 to 4095) that
	// this is.

	triceratopsAngle = 4096 * linearPosition / (BACK_OFF_CIRCUMFERENCE);
	triceratopsAngle &= 4096-1;

	triceratopsHMD.position.vx = BACK_OFF_DISTANCE * rsin(triceratopsAngle) / ONE;
	triceratopsHMD.position.vz = BACK_OFF_DISTANCE * rcos(triceratopsAngle) / ONE;
	triceratopsHMD.rotate.vy = (triceratopsAngle + 4096 / 4) & (4096-1);

	if(animFrameCount == 0) {
		lastStatePosition += linearPosition;
	}

		// Copies this frame's 3 Euler rotation values into
		// the coordinate systems.

	op++;
	rotation = &animDataArea->Rotation[animFrameIndex * animDataArea->NumJoints];
	for(i = 0; i < animDataArea->NumJoints; i++, op++,rotation++) {
		op->coord->rot.vx = rotation->vx;
		op->coord->rot.vy = rotation->vy;
		op->coord->rot.vz = rotation->vz;
	}

		// This check starts the sound/rumble/screen shake at the middle of
		// the stomp cycle, not the start. Otherwise we'd hear the stomp before
		// the dinosaur's foot had hit the ground.

	if(currentState == STOMP && animFrameCount == 10) {
		doStompSound();
		AddLump(20);
		doShock();
		StompStatus = FALSE;
		CameraShudderFrame = 7;
		desiredState = STOPPED;
	}

		// This will shudder the camera due to the foot stomp.
	if(CameraShudderFrame >= 0) {
		CameraShudder_UD += 20 * ((CameraShudderFrame & 1)?1:-1);
		CameraShudderFrame--;
	}

#ifdef MESSAGES_ON
	FntPrint("Frame: %d\n",animFrameIndex);
	FntPrint("Z translation: %d   To go: %d\n",animDataArea->Translation[animFrameIndex].vz,animFrameCount);
	FntPrint("linearPosition: %d\n",linearPosition);
#endif

	animFrameIndex++;
	animFrameCount--;
}

// ========================================================================

	// This function will insert the reflection triceratops into the reflection
	// ordering table.

	// Because the rotation matrices for the reflected version are the same
	// as the matrices for the normal version, they are only calculated once.
	// The GsCOORDUNIT structure provides space to store the product of a
	// matrix and all its parents, which means we don't have to recalculate
	// that either.

	// These matrices don't change for the normal (non-reflected) triceratops,
	// so we re-use them later on which means we don't have to do so many calculations

void ProcessTriceratopsReflectionHMD(bool drawTTopsFlag) {
	SVECTOR tempRot;
	GsUNIT *op;
	int
		i,
		tailAnimRate = 0,
		tailAddition = 0,
		mouthMoveUpDown = 0;

	RotMatrix_gte(&triceratopsHMD.rotate, &triceratopsHMD.root.workm);
	triceratopsHMD.root.workm.t[0] = triceratopsHMD.position.vx;
	triceratopsHMD.root.workm.t[1] = triceratopsHMD.position.vy;
	triceratopsHMD.root.workm.t[2] = triceratopsHMD.position.vz;

			// These checks will add to certain Euler angles if the
			// tail or mouth are moving.

	if(tailAnimFrame > 0) {
		tailAnimRate = rcos(tailAnimFrame);
		tailAnimFrame -= 5;
		tailAddition = 4096 - rsin(tailAnimRate) / 10;

	}

	if(mouthMoveFrame != 0) {
		mouthMoveUpDown = rsin(mouthMoveFrame) / 14;
		mouthMoveFrame += (roarNumber == 1)?20:13;
		if(mouthMoveFrame >= ONE/2) {
			mouthMoveFrame = 0;
		}
	}

		// We do all the RotMatrix's in one loop to (try to) preserve
		// cache coherency. In the next loop, we load the calculated matrix
		// and multiply it by into the GTE and sort the polygons.

	op = triceratopsHMD.primBlocks;
	for(i = 0; i < triceratopsHMD.numPrimBlocks; i++, op++) {
		if(op->coord) {	// If this primitive block has a coordinate
				// Adjust rotation of some coordinate systems in
				//	response to controller

				// Create Local->World matrix

					// First create rotation matrix
			if(tailAnimRate != 0 && (i == 21 || i == 22)) {
				tempRot = op->coord->rot;
				tempRot.vy += tailAddition;
				RotMatrix_gte(&tempRot,&op->coord->workm);
			} else if(i == 5) {
				tempRot = op->coord->rot;
				tempRot.vy += headMoveLeftRight;
				tempRot.vx += headMoveUpDown;
				RotMatrix_gte(&tempRot,&op->coord->workm);
			} else if(i == 6) {
				tempRot = op->coord->rot;
				tempRot.vx += mouthMoveUpDown;
				RotMatrix_gte(&tempRot,&op->coord->workm);
			} else {
				RotMatrix_gte(&op->coord->rot,&op->coord->workm);
			}
			op->coord->workm.t[0] = triceratopsHMD.translations[i].vx;
			op->coord->workm.t[1] = triceratopsHMD.translations[i].vy;
			op->coord->workm.t[2] = triceratopsHMD.translations[i].vz;
				// Now multiply it by its parent (every coordinate
				// system has a parent, even the top one - this is
				// because the extra coordinate system in the handler
				// is added at to the top during initialisation).

				// Because all the coord systems are in top down order
				// (no child comes in the list before it's parent), this
				// is the most efficient way of calculating the Local->World
				// matrix. We store this in op->coord->workm, and store the
				// Local->World->Screen matrix in op->coord->matrix.

			GsMulCoord2(&op->coord->super->workm,&op->coord->workm);
			op->coord->matrix = op->coord->workm;
				// Now both workm and matrix contain the Local->World matrix.

				// Create the Local->World->Screen matrix.
			GsMulCoord2(&GsWSMATRIX, &op->coord->matrix);
		}
	}

		// We don't draw the ttops in the reflection if it won't be seen in the reflection.
		// but we still have to process all its coordinate systems, because they
		// will be used for the normal dinosaur.
	if(drawTTopsFlag) {
		op = triceratopsHMD.primBlocks;
		for(i = 0; i < triceratopsHMD.numPrimBlocks; i++, op++) {
			if(op->primtop == NULL) {
				continue;
			}
			if(op->coord) {	// If this primitive block has a coordinate
				SetRotMatrix(&op->coord->matrix);		// Load in the Local->World->Screen
				SetTransMatrix(&op->coord->matrix);
			}
			GsSortUnit(op, &reflectionOT[g_ScreenBufferNum],getScratchAddr(0));
		}
	}

}

// ========================================================================
	// This function assumes that the reflection model has been processed.
	// If this is the case, the Local->World matrices will all be valid,
	// all that has to be done is that they are multiplied by the World->Screen
	// matrix and they will be correct. This method reduces processing time,
	// because we aren't calculating the same matrices more than once.

void ProcessTriceratopsHMD(void) {
	int i;
	GsUNIT *op = triceratopsHMD.primBlocks;

	for(i = 0; i < triceratopsHMD.numPrimBlocks; i++, op++) {
		if(op->primtop == NULL) {
			continue;
		}
		if(op->coord) {
				// This uses the current local->world to calculate
				// the local->world->screen matrix. It will DESTROY
				// the local to world matrix. Technically, we should
				// reset the coordinate's flg to 0 to say that the
				// workm is invalid, but we'll do that anyway in the
				// next frame.
			GsMulCoord2(&GsWSMATRIX, &op->coord->workm);
			SetRotMatrix(&op->coord->workm);
			SetTransMatrix(&op->coord->workm);
		}
		GsSortUnit(op, &mainOT[g_ScreenBufferNum],getScratchAddr(0));
	}
}

// ========================================================================
	// This function will process the environment HMD and the innermost tree HMD.
	// The reason we are using one function is for speed - they share exactly
	// the same coordinate system, so it would be inefficient to process
	// both of them separately. Instead, we just calculate the matrix once (using
	// the main environment as the coordinate system 'authority', and ignore
	// the values of position/rotation in the 'innermost tree' model.

void ProcessEnvironmentHMDModels(void) {
	MATRIX tmpls;
	HMD_ObjectHandler *hmd;
	GsUNIT *envOp;
	GsUNIT *treeOp = &innerTreeHMD.primBlocks[1];

	if(introModeOn) {	// Select environment model.
		hmd = &environmentHMD;
	} else {
		hmd = &environmentNPHMD;
	}
	envOp = &hmd->primBlocks[1];

			// Calculate the Local matrix (= Local->World).
	RotMatrix_gte(&hmd->rotate, &hmd->root.matrix);

	hmd->root.flg = 0;

	RotMatrix_gte(&envOp->coord->rot,&envOp->coord->matrix);

	GsGetLsUnit(envOp->coord,&tmpls);
	SetRotMatrix(&tmpls);		// Load it into the GTE
	SetTransMatrix(&tmpls);

			// Draw both the innermost tree and the environment.
	GsSortUnit(envOp, &groundOT[g_ScreenBufferNum],getScratchAddr(0));
	GsSortUnit(treeOp, &mainOT[g_ScreenBufferNum],getScratchAddr(0));
}

// ========================================================================
	// This function is a generic HMD render loop. For each primitive block,
	// it calculates the Local->World->Screen matrix, puts it into the
	// GTE, and renders the primitive block

void ProcessHMDModel(HMD_ObjectHandler *hmd, GsOT *ot) {
	int i;
	MATRIX tmpls;
	GsUNIT *op = hmd->primBlocks;

	RotMatrix_gte(&hmd->rotate, &hmd->root.matrix);
	hmd->root.matrix.t[0] = hmd->position.vx;
	hmd->root.matrix.t[1] = hmd->position.vy;
	hmd->root.matrix.t[2] = hmd->position.vz;
	hmd->root.flg = 0;

	for(i = 0; i < hmd->numPrimBlocks; i++, op++) {
		if(op->primtop == NULL) {
			continue;
		}
		if(op->coord) {	// If this primitive block has a coordinate
			if(op->coord->flg == 0) {
				RotMatrix_gte(&op->coord->rot,&op->coord->matrix);
			}
			GsGetLsUnit(op->coord,&tmpls);
			GsSetLsMatrix(&tmpls);
		}
		GsSortUnit(op, ot,getScratchAddr(0));
	}
}
