/*
	Scanning routine for all of category 3 animation primitive types.

	Copyright (C) 1997,1998  Sony Computer Entertainment Inc.
	All rights Reserved.

	Ver 1.00	Dec 09, 1997	By N. Yoshioka
	Ver 1.10	Jan 12, 1998	By N. Yoshioka
	Ver 1.20	Mar 19, 1998	By N. Yoshioka
		- New animations
*/

#include <sys/types.h>
#include <libgte.h>
#include <libgpu.h>
#include <libgs.h>
#include "libhmd.h"
#include <stdio.h>
#include <assert.h>
#include "scan.h"

u_long
scan_anim(u_long type)
{
	/* CTG 3: ANIMATION */

	GsUNIT_AnimFuncp	func = NULL;

	assert((type >> 24) == 0x03);

	switch (type) {
//	// case 0x03800000:	func = GsU_03000000;	break;
	default:
		printf("unsupported ANIMATION primitive 0x%08x.\n", type);
		exit(1);
	}

	return (u_long)func;
}

void
scan_interp(void)
{
	/* CTG 3: ANIMATION's interpolation function */

	GsTYPEUNIT	ut;
	GsUNIT_InterpFuncp	func = NULL;

	while (GsScanAnim(0, &ut)) {
		assert((ut.type >> 24) == 0x03);
		switch (ut.type) {
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_NONE|TI_LINEAR); */
		// case 0x03000001:	func = GsU_03000001;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_NONE|TI_BEZIER); */
		// case 0x03000002:	func = GsU_03000002;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_NONE|TI_BSPLINE); */
		// case 0x03000003:	func = GsU_03000003;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_NONE|TI_LINEAR_S); */
		// case 0x03000009:	func = GsU_03000009;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_NONE|TI_BEZIER_S); */
		// case 0x0300000a:	func = GsU_0300000a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_NONE|TI_BSPLINE_S); */
		// case 0x0300000b:	func = GsU_0300000b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XYZ|TI_NONE); */
		// case 0x03000010:	func = GsU_03000010;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XYZ|TI_LINEAR); */
		// case 0x03000011:	func = GsU_03000011;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XYZ|TI_BEZIER); */
		// case 0x03000012:	func = GsU_03000012;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XYZ|TI_BSPLINE); */
		// case 0x03000013:	func = GsU_03000013;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XYZ|TI_LINEAR_S); */
		// case 0x03000019:	func = GsU_03000019;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XYZ|TI_BEZIER_S); */
		// case 0x0300001a:	func = GsU_0300001a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XYZ|TI_BSPLINE_S); */
		// case 0x0300001b:	func = GsU_0300001b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XYZ|TI_NONE); */
		// case 0x03000020:	func = GsU_03000020;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XYZ|TI_LINEAR); */
		// case 0x03000021:	func = GsU_03000021;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XYZ|TI_BEZIER); */
		// case 0x03000022:	func = GsU_03000022;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XYZ|TI_BSPLINE); */
		// case 0x03000023:	func = GsU_03000023;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XYZ|TI_LINEAR_S); */
		// case 0x03000029:	func = GsU_03000029;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XYZ|TI_BEZIER_S); */
		// case 0x0300002a:	func = GsU_0300002a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XYZ|TI_BSPLINE_S); */
		// case 0x0300002b:	func = GsU_0300002b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XYZ|TI_NONE); */
		// case 0x03000030:	func = GsU_03000030;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XYZ|TI_LINEAR); */
		// case 0x03000031:	func = GsU_03000031;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XYZ|TI_BEZIER); */
		// case 0x03000032:	func = GsU_03000032;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XYZ|TI_BSPLINE); */
		// case 0x03000033:	func = GsU_03000033;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XYZ|TI_LINEAR_S); */
		// case 0x03000039:	func = GsU_03000039;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XYZ|TI_BEZIER_S); */
		// case 0x0300003a:	func = GsU_0300003a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XYZ|TI_BSPLINE_S); */
		// case 0x0300003b:	func = GsU_0300003b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_NONE|TI_NONE); */
		// case 0x03000100:	func = GsU_03000100;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_XYZ|TI_LINEAR); */
		// case 0x03000111:	func = GsU_03000111;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_XYZ|TI_BEZIER); */
		// case 0x03000112:	func = GsU_03000112;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_XYZ|TI_LINEAR_S); */
		// case 0x03000119:	func = GsU_03000119;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_XYZ|TI_BEZIER_S); */
		// case 0x0300011a:	func = GsU_0300011a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_NONE|TI_LINEAR); */
		// case 0x03000901:	func = GsU_03000901;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_NONE|TI_BEZIER); */
		// case 0x03000902:	func = GsU_03000902;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_NONE|TI_LINEAR_S); */
		// case 0x03000909:	func = GsU_03000909;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_NONE|TI_BEZIER_S); */
		// case 0x0300090a:	func = GsU_0300090a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XYZ|TI_NONE); */
		// case 0x03000910:	func = GsU_03000910;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XYZ|TI_LINEAR); */
		// case 0x03000911:	func = GsU_03000911;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XYZ|TI_BEZIER); */
		// case 0x03000912:	func = GsU_03000912;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XYZ|TI_LINEAR_S); */
		// case 0x03000919:	func = GsU_03000919;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XYZ|TI_BEZIER_S); */
		// case 0x0300091a:	func = GsU_0300091a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XZY|TI_NONE); */
		// case 0x03001010:	func = GsU_03001010;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XZY|TI_LINEAR); */
		// case 0x03001011:	func = GsU_03001011;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XZY|TI_BEZIER); */
		// case 0x03001012:	func = GsU_03001012;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XZY|TI_BSPLINE); */
		// case 0x03001013:	func = GsU_03001013;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XZY|TI_LINEAR_S); */
		// case 0x03001019:	func = GsU_03001019;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XZY|TI_BEZIER_S); */
		// case 0x0300101a:	func = GsU_0300101a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_XZY|TI_BSPLINE_S); */
		// case 0x0300101b:	func = GsU_0300101b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XZY|TI_NONE); */
		// case 0x03001020:	func = GsU_03001020;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XZY|TI_LINEAR); */
		// case 0x03001021:	func = GsU_03001021;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XZY|TI_BEZIER); */
		// case 0x03001022:	func = GsU_03001022;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XZY|TI_BSPLINE); */
		// case 0x03001023:	func = GsU_03001023;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XZY|TI_LINEAR_S); */
		// case 0x03001029:	func = GsU_03001029;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XZY|TI_BEZIER_S); */
		// case 0x0300102a:	func = GsU_0300102a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_XZY|TI_BSPLINE_S); */
		// case 0x0300102b:	func = GsU_0300102b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XZY|TI_NONE); */
		// case 0x03001030:	func = GsU_03001030;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XZY|TI_LINEAR); */
		// case 0x03001031:	func = GsU_03001031;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XZY|TI_BEZIER); */
		// case 0x03001032:	func = GsU_03001032;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XZY|TI_BSPLINE); */
		// case 0x03001033:	func = GsU_03001033;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XZY|TI_LINEAR_S); */
		// case 0x03001039:	func = GsU_03001039;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XZY|TI_BEZIER_S); */
		// case 0x0300103a:	func = GsU_0300103a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_XZY|TI_BSPLINE_S); */
		// case 0x0300103b:	func = GsU_0300103b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_XZY|TI_LINEAR); */
		// case 0x03001111:	func = GsU_03001111;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_XZY|TI_BEZIER); */
		// case 0x03001112:	func = GsU_03001112;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_XZY|TI_LINEAR_S); */
		// case 0x03001119:	func = GsU_03001119;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_XZY|TI_BEZIER_S); */
		// case 0x0300111a:	func = GsU_0300111a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XZY|TI_NONE); */
		// case 0x03001910:	func = GsU_03001910;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XZY|TI_LINEAR); */
		// case 0x03001911:	func = GsU_03001911;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XZY|TI_BEZIER); */
		// case 0x03001912:	func = GsU_03001912;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XZY|TI_LINEAR_S); */
		// case 0x03001919:	func = GsU_03001919;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_XZY|TI_BEZIER_S); */
		// case 0x0300191a:	func = GsU_0300191a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YXZ|TI_NONE); */
		// case 0x03002010:	func = GsU_03002010;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YXZ|TI_LINEAR); */
		// case 0x03002011:	func = GsU_03002011;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YXZ|TI_BEZIER); */
		// case 0x03002012:	func = GsU_03002012;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YXZ|TI_BSPLINE); */
		// case 0x03002013:	func = GsU_03002013;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YXZ|TI_LINEAR_S); */
		// case 0x03002019:	func = GsU_03002019;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YXZ|TI_BEZIER_S); */
		// case 0x0300201a:	func = GsU_0300201a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YXZ|TI_BSPLINE_S); */
		// case 0x0300201b:	func = GsU_0300201b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YXZ|TI_NONE); */
		// case 0x03002020:	func = GsU_03002020;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YXZ|TI_LINEAR); */
		// case 0x03002021:	func = GsU_03002021;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YXZ|TI_BEZIER); */
		// case 0x03002022:	func = GsU_03002022;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YXZ|TI_BSPLINE); */
		// case 0x03002023:	func = GsU_03002023;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YXZ|TI_LINEAR_S); */
		// case 0x03002029:	func = GsU_03002029;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YXZ|TI_BEZIER_S); */
		// case 0x0300202a:	func = GsU_0300202a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YXZ|TI_BSPLINE_S); */
		// case 0x0300202b:	func = GsU_0300202b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YXZ|TI_NONE); */
		// case 0x03002030:	func = GsU_03002030;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YXZ|TI_LINEAR); */
		// case 0x03002031:	func = GsU_03002031;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YXZ|TI_BEZIER); */
		// case 0x03002032:	func = GsU_03002032;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YXZ|TI_BSPLINE); */
		// case 0x03002033:	func = GsU_03002033;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YXZ|TI_LINEAR_S); */
		// case 0x03002039:	func = GsU_03002039;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YXZ|TI_BEZIER_S); */
		// case 0x0300203a:	func = GsU_0300203a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YXZ|TI_BSPLINE_S); */
		// case 0x0300203b:	func = GsU_0300203b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_YXZ|TI_LINEAR); */
		// case 0x03002111:	func = GsU_03002111;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_YXZ|TI_BEZIER); */
		// case 0x03002112:	func = GsU_03002112;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_YXZ|TI_LINEAR_S); */
		// case 0x03002119:	func = GsU_03002119;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_YXZ|TI_BEZIER_S); */
		// case 0x0300211a:	func = GsU_0300211a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YXZ|TI_NONE); */
		// case 0x03002910:	func = GsU_03002910;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YXZ|TI_LINEAR); */
		// case 0x03002911:	func = GsU_03002911;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YXZ|TI_BEZIER); */
		// case 0x03002912:	func = GsU_03002912;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YXZ|TI_LINEAR_S); */
		// case 0x03002919:	func = GsU_03002919;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YXZ|TI_BEZIER_S); */
		// case 0x0300291a:	func = GsU_0300291a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YZX|TI_NONE); */
		// case 0x03003010:	func = GsU_03003010;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YZX|TI_LINEAR); */
		// case 0x03003011:	func = GsU_03003011;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YZX|TI_BEZIER); */
		// case 0x03003012:	func = GsU_03003012;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YZX|TI_BSPLINE); */
		// case 0x03003013:	func = GsU_03003013;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YZX|TI_LINEAR_S); */
		// case 0x03003019:	func = GsU_03003019;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YZX|TI_BEZIER_S); */
		// case 0x0300301a:	func = GsU_0300301a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_YZX|TI_BSPLINE_S); */
		// case 0x0300301b:	func = GsU_0300301b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YZX|TI_NONE); */
		// case 0x03003020:	func = GsU_03003020;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YZX|TI_LINEAR); */
		// case 0x03003021:	func = GsU_03003021;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YZX|TI_BEZIER); */
		// case 0x03003022:	func = GsU_03003022;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YZX|TI_BSPLINE); */
		// case 0x03003023:	func = GsU_03003023;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YZX|TI_LINEAR_S); */
		// case 0x03003029:	func = GsU_03003029;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YZX|TI_BEZIER_S); */
		// case 0x0300302a:	func = GsU_0300302a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_YZX|TI_BSPLINE_S); */
		// case 0x0300302b:	func = GsU_0300302b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YZX|TI_NONE); */
		// case 0x03003030:	func = GsU_03003030;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YZX|TI_LINEAR); */
		// case 0x03003031:	func = GsU_03003031;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YZX|TI_BEZIER); */
		// case 0x03003032:	func = GsU_03003032;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YZX|TI_BSPLINE); */
		// case 0x03003033:	func = GsU_03003033;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YZX|TI_LINEAR_S); */
		// case 0x03003039:	func = GsU_03003039;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YZX|TI_BEZIER_S); */
		// case 0x0300303a:	func = GsU_0300303a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_YZX|TI_BSPLINE_S); */
		// case 0x0300303b:	func = GsU_0300303b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_YZX|TI_LINEAR); */
		// case 0x03003111:	func = GsU_03003111;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_YZX|TI_BEZIER); */
		// case 0x03003112:	func = GsU_03003112;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_YZX|TI_LINEAR_S); */
		// case 0x03003119:	func = GsU_03003119;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_YZX|TI_BEZIER_S); */
		// case 0x0300311a:	func = GsU_0300311a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YZX|TI_NONE); */
		// case 0x03003910:	func = GsU_03003910;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YZX|TI_LINEAR); */
		// case 0x03003911:	func = GsU_03003911;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YZX|TI_BEZIER); */
		// case 0x03003912:	func = GsU_03003912;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YZX|TI_LINEAR_S); */
		// case 0x03003919:	func = GsU_03003919;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_YZX|TI_BEZIER_S); */
		// case 0x0300391a:	func = GsU_0300391a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZXY|TI_NONE); */
		// case 0x03004010:	func = GsU_03004010;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZXY|TI_LINEAR); */
		// case 0x03004011:	func = GsU_03004011;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZXY|TI_BEZIER); */
		// case 0x03004012:	func = GsU_03004012;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZXY|TI_BSPLINE); */
		// case 0x03004013:	func = GsU_03004013;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZXY|TI_LINEAR_S); */
		// case 0x03004019:	func = GsU_03004019;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZXY|TI_BEZIER_S); */
		// case 0x0300401a:	func = GsU_0300401a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZXY|TI_BSPLINE_S); */
		// case 0x0300401b:	func = GsU_0300401b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZXY|TI_NONE); */
		// case 0x03004020:	func = GsU_03004020;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZXY|TI_LINEAR); */
		// case 0x03004021:	func = GsU_03004021;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZXY|TI_BEZIER); */
		// case 0x03004022:	func = GsU_03004022;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZXY|TI_BSPLINE); */
		// case 0x03004023:	func = GsU_03004023;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZXY|TI_LINEAR_S); */
		// case 0x03004029:	func = GsU_03004029;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZXY|TI_BEZIER_S); */
		// case 0x0300402a:	func = GsU_0300402a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZXY|TI_BSPLINE_S); */
		// case 0x0300402b:	func = GsU_0300402b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZXY|TI_NONE); */
		// case 0x03004030:	func = GsU_03004030;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZXY|TI_LINEAR); */
		// case 0x03004031:	func = GsU_03004031;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZXY|TI_BEZIER); */
		// case 0x03004032:	func = GsU_03004032;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZXY|TI_BSPLINE); */
		// case 0x03004033:	func = GsU_03004033;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZXY|TI_LINEAR_S); */
		// case 0x03004039:	func = GsU_03004039;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZXY|TI_BEZIER_S); */
		// case 0x0300403a:	func = GsU_0300403a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZXY|TI_BSPLINE_S); */
		// case 0x0300403b:	func = GsU_0300403b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_ZXY|TI_LINEAR); */
		// case 0x03004111:	func = GsU_03004111;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_ZXY|TI_BEZIER); */
		// case 0x03004112:	func = GsU_03004112;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_ZXY|TI_LINEAR_S); */
		// case 0x03004119:	func = GsU_03004119;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_ZXY|TI_BEZIER_S); */
		// case 0x0300411a:	func = GsU_0300411a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZXY|TI_NONE); */
		// case 0x03004910:	func = GsU_03004910;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZXY|TI_LINEAR); */
		// case 0x03004911:	func = GsU_03004911;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZXY|TI_BEZIER); */
		// case 0x03004912:	func = GsU_03004912;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZXY|TI_LINEAR_S); */
		// case 0x03004919:	func = GsU_03004919;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZXY|TI_BEZIER_S); */
		// case 0x0300491a:	func = GsU_0300491a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZYX|TI_NONE); */
		// case 0x03005010:	func = GsU_03005010;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZYX|TI_LINEAR); */
		// case 0x03005011:	func = GsU_03005011;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZYX|TI_BEZIER); */
		// case 0x03005012:	func = GsU_03005012;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZYX|TI_BSPLINE); */
		// case 0x03005013:	func = GsU_03005013;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZYX|TI_LINEAR_S); */
		// case 0x03005019:	func = GsU_03005019;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZYX|TI_BEZIER_S); */
		// case 0x0300501a:	func = GsU_0300501a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_LINEAR|ROT_ZYX|TI_BSPLINE_S); */
		// case 0x0300501b:	func = GsU_0300501b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZYX|TI_NONE); */
		// case 0x03005020:	func = GsU_03005020;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZYX|TI_LINEAR); */
		// case 0x03005021:	func = GsU_03005021;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZYX|TI_BEZIER); */
		// case 0x03005022:	func = GsU_03005022;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZYX|TI_BSPLINE); */
		// case 0x03005023:	func = GsU_03005023;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZYX|TI_LINEAR_S); */
		// case 0x03005029:	func = GsU_03005029;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZYX|TI_BEZIER_S); */
		// case 0x0300502a:	func = GsU_0300502a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BEZIER|ROT_ZYX|TI_BSPLINE_S); */
		// case 0x0300502b:	func = GsU_0300502b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZYX|TI_NONE); */
		// case 0x03005030:	func = GsU_03005030;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZYX|TI_LINEAR); */
		// case 0x03005031:	func = GsU_03005031;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZYX|TI_BEZIER); */
		// case 0x03005032:	func = GsU_03005032;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZYX|TI_BSPLINE); */
		// case 0x03005033:	func = GsU_03005033;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZYX|TI_LINEAR_S); */
		// case 0x03005039:	func = GsU_03005039;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZYX|TI_BEZIER_S); */
		// case 0x0300503a:	func = GsU_0300503a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_NONE|RI_BSPLINE|ROT_ZYX|TI_BSPLINE_S); */
		// case 0x0300503b:	func = GsU_0300503b;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_ZYX|TI_LINEAR); */
		// case 0x03005111:	func = GsU_03005111;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_ZYX|TI_BEZIER); */
		// case 0x03005112:	func = GsU_03005112;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_ZYX|TI_LINEAR_S); */
		// case 0x03005119:	func = GsU_03005119;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR|RI_LINEAR|ROT_ZYX|TI_BEZIER_S); */
		// case 0x0300511a:	func = GsU_0300511a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZYX|TI_NONE); */
		// case 0x03005910:	func = GsU_03005910;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZYX|TI_LINEAR); */
		// case 0x03005911:	func = GsU_03005911;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZYX|TI_BEZIER); */
		// case 0x03005912:	func = GsU_03005912;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZYX|TI_LINEAR_S); */
		// case 0x03005919:	func = GsU_03005919;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_COORD)|PRIM_TYPE(SI_LINEAR_1|RI_LINEAR|ROT_ZYX|TI_BEZIER_S); */
		// case 0x0300591a:	func = GsU_0300591a;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x1)|GI_32); */
		// case 0x03010110:	func = GsU_03010110;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x1)|GI_16); */
		// case 0x03010111:	func = GsU_03010111;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x1)|GI_8); */
		// case 0x03010112:	func = GsU_03010112;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x2)|GI_16); */
		// case 0x03010121:	func = GsU_03010121;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x2)|GI_8); */
		// case 0x03010122:	func = GsU_03010122;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x4)|GI_16); */
		// case 0x03010141:	func = GsU_03010141;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x4)|GI_8); */
		// case 0x03010142:	func = GsU_03010142;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x7)|GI_16); */
		// case 0x03010171:	func = GsU_03010171;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x7)|GI_8); */
		// case 0x03010172:	func = GsU_03010172;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_LINEAR|GI_WR(0x8)|GI_8); */
		// case 0x03010182:	func = GsU_03010182;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x1)|GI_32); */
		// case 0x03010210:	func = GsU_03010210;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x1)|GI_16); */
		// case 0x03010211:	func = GsU_03010211;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x1)|GI_8); */
		// case 0x03010212:	func = GsU_03010212;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x2)|GI_16); */
		// case 0x03010221:	func = GsU_03010221;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x2)|GI_8); */
		// case 0x03010222:	func = GsU_03010222;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x4)|GI_16); */
		// case 0x03010241:	func = GsU_03010241;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x4)|GI_8); */
		// case 0x03010242:	func = GsU_03010242;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x7)|GI_16); */
		// case 0x03010271:	func = GsU_03010271;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BEZIER|GI_WR(0x7)|GI_8); */
		// case 0x03010272:	func = GsU_03010272;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x1)|GI_32); */
		// case 0x03010310:	func = GsU_03010310;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x1)|GI_16); */
		// case 0x03010311:	func = GsU_03010311;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x1)|GI_8); */
		// case 0x03010312:	func = GsU_03010312;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x2)|GI_16); */
		// case 0x03010321:	func = GsU_03010321;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x2)|GI_8); */
		// case 0x03010322:	func = GsU_03010322;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x4)|GI_16); */
		// case 0x03010341:	func = GsU_03010341;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x4)|GI_8); */
		// case 0x03010342:	func = GsU_03010342;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x7)|GI_16); */
		// case 0x03010371:	func = GsU_03010371;	break;
		/* DEV_ID(SCE)|CTG(CTG_ANIM)|DRV(CAT_STD|TGT_GENERAL)|PRIM_TYPE(GI_BSPLINE|GI_WR(0x7)|GI_8); */
		// case 0x03010372:	func = GsU_03010372;	break;
		default:
			printf("unsupported ANIMATION interpolation 0x%08x.\n",
				ut.type);
			exit(1);
//			func = (GsUNIT_InterpFuncp)GsU_03000000;
		}
		*ut.ptr = (u_long)func;
	}
}
