/*
	Scanning routine for all of category 0 polygon primitive types.

	Copyright (C) 1997,1998  Sony Computer Entertainment Inc.
	All rights Reserved.

	Ver 1.00	Dec 09, 1997	By N. Yoshioka
	Ver 1.10	Jan 12, 1998	By N. Yoshioka
	Ver 1.20	Mar 03, 1998	By N. Yoshioka
		- New primitives are added.
*/

#include <sys/types.h>
#include <libgte.h>
#include <libgpu.h>
#include <libgs.h>
#include "libhmd.h"
#include <stdio.h>
#include <assert.h>
#include "scan.h"

u_long
scan_poly(u_long type)
{
	/* CTG 0: POLY or NULL */

	GsUNIT_Funcp	func = NULL;

	assert((type >> 24) == 0x00);

	switch (type) {
	case 0x00000000:
#ifdef DEBUG
		printf("DEBUG:pointer is already set\n");
#endif /* DEBUG */
		func = GsU_00000000;
		break;

	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TRI); */
//	case 0x00000008:	func = GsU_00000008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TRI|TME); */
//	case 0x00000009:	func = GsU_00000009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TRI|COL); */
//	case 0x0000000a:	func = GsU_0000000a;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TRI|COL|TME); */
//	case 0x0000000b:	func = GsU_0000000b;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TRI|IIP); */
//	case 0x0000000c:	func = GsU_0000000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TRI|IIP|TME); */
//	case 0x0000000d:	func = GsU_0000000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TRI|IIP|COL); */
//	case 0x0000000e:	func = GsU_0000000e;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TRI|IIP|COL|TME); */
//	case 0x0000000f:	func = GsU_0000000f;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(QUAD); */
//	case 0x00000010:	func = GsU_00000010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(QUAD|TME); */
//	case 0x00000011:	func = GsU_00000011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(QUAD|COL); */
//	case 0x00000012:	func = GsU_00000012;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(QUAD|COL|TME); */
//	case 0x00000013:	func = GsU_00000013;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(QUAD|IIP); */
//	case 0x00000014:	func = GsU_00000014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(QUAD|IIP|TME); */
//	case 0x00000015:	func = GsU_00000015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(QUAD|IIP|COL); */
//	case 0x00000016:	func = GsU_00000016;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(QUAD|IIP|COL|TME); */
//	case 0x00000017:	func = GsU_00000017;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(MESH); */
//	case 0x00000018:	func = GsU_00000018;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(MESH|TME); */
//	case 0x00000019:	func = GsU_00000019;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(MESH|IIP); */
//	case 0x0000001c:	func = GsU_0000001c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(MESH|IIP|TME); */
//	case 0x0000001d:	func = GsU_0000001d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TILE|TRI|TME); */
//	case 0x00000209:	func = GsU_00000209;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TILE|TRI|IIP|TME); */
//	case 0x0000020d:	func = GsU_0000020d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TILE|QUAD|TME); */
//	case 0x00000211:	func = GsU_00000211;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(0)|PRIM_TYPE(TILE|QUAD|IIP|TME); */
//	case 0x00000215:	func = GsU_00000215;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(DIV)|PRIM_TYPE(TRI); */
//	case 0x00010008:	func = GsU_00010008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(DIV)|PRIM_TYPE(TRI|TME); */
//	case 0x00010009:	func = GsU_00010009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(DIV)|PRIM_TYPE(TRI|IIP); */
//	case 0x0001000c:	func = GsU_0001000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(DIV)|PRIM_TYPE(TRI|IIP|TME); */
//	case 0x0001000d:	func = GsU_0001000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(DIV)|PRIM_TYPE(QUAD); */
//	case 0x00010010:	func = GsU_00010010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(DIV)|PRIM_TYPE(QUAD|TME); */
//	case 0x00010011:	func = GsU_00010011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(DIV)|PRIM_TYPE(QUAD|IIP); */
//	case 0x00010014:	func = GsU_00010014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(DIV)|PRIM_TYPE(QUAD|IIP|TME); */
//	case 0x00010015:	func = GsU_00010015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(TRI); */
//	case 0x00020008:	func = GsU_00020008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(TRI|TME); */
//	case 0x00020009:	func = GsU_00020009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(TRI|COL); */
//	case 0x0002000a:	func = GsU_0002000a;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(TRI|COL|TME); */
//	case 0x0002000b:	func = GsU_0002000b;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(TRI|IIP); */
//	case 0x0002000c:	func = GsU_0002000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(TRI|IIP|TME); */
//	case 0x0002000d:	func = GsU_0002000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(TRI|IIP|COL); */
//	case 0x0002000e:	func = GsU_0002000e;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(TRI|IIP|COL|TME); */
//	case 0x0002000f:	func = GsU_0002000f;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(QUAD); */
//	case 0x00020010:	func = GsU_00020010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(QUAD|TME); */
//	case 0x00020011:	func = GsU_00020011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(QUAD|COL); */
//	case 0x00020012:	func = GsU_00020012;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(QUAD|COL|TME); */
//	case 0x00020013:	func = GsU_00020013;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(QUAD|IIP); */
//	case 0x00020014:	func = GsU_00020014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(QUAD|IIP|TME); */
//	case 0x00020015:	func = GsU_00020015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(QUAD|IIP|COL); */
//	case 0x00020016:	func = GsU_00020016;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG)|PRIM_TYPE(QUAD|IIP|COL|TME); */
//	case 0x00020017:	func = GsU_00020017;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG|DIV)|PRIM_TYPE(TRI); */
//	case 0x00030008:	func = GsU_00030008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG|DIV)|PRIM_TYPE(TRI|TME); */
//	case 0x00030009:	func = GsU_00030009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG|DIV)|PRIM_TYPE(TRI|IIP); */
//	case 0x0003000c:	func = GsU_0003000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG|DIV)|PRIM_TYPE(TRI|IIP|TME); */
//	case 0x0003000d:	func = GsU_0003000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG|DIV)|PRIM_TYPE(QUAD); */
//	case 0x00030010:	func = GsU_00030010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG|DIV)|PRIM_TYPE(QUAD|TME); */
//	case 0x00030011:	func = GsU_00030011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG|DIV)|PRIM_TYPE(QUAD|IIP); */
//	case 0x00030014:	func = GsU_00030014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(FOG|DIV)|PRIM_TYPE(QUAD|IIP|TME); */
//	case 0x00030015:	func = GsU_00030015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|TRI); */
	case 0x00040048:	func = GsU_00040048;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|TRI|TME); */
	case 0x00040049:	func = GsU_00040049;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|TRI|IIP); */
	case 0x0004004c:	func = GsU_0004004c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|TRI|IIP|TME); */
	case 0x0004004d:	func = GsU_0004004d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|QUAD); */
	case 0x00040050:	func = GsU_00040050;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|QUAD|TME); */
	case 0x00040051:	func = GsU_00040051;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|QUAD|IIP); */
	case 0x00040054:	func = GsU_00040054;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|QUAD|IIP|TME); */
	case 0x00040055:	func = GsU_00040055;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|MESH); */
	case 0x00040058:	func = GsU_00040058;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|MESH|TME); */
	case 0x00040059:	func = GsU_00040059;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|MESH|IIP); */
	case 0x0004005c:	func = GsU_0004005c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(LMD|MESH|IIP|TME); */
	case 0x0004005d:	func = GsU_0004005d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(PST|LMD|TRI); */
//	case 0x00040148:	func = GsU_00040148;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(PST|LMD|TRI|TME); */
//	case 0x00040149:	func = GsU_00040149;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(PST|LMD|TRI|IIP); */
//	case 0x0004014c:	func = GsU_0004014c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(PST|LMD|TRI|IIP|TME); */
//	case 0x0004014d:	func = GsU_0004014d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(PST|LMD|QUAD); */
//	case 0x00040150:	func = GsU_00040150;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(PST|LMD|QUAD|TME); */
//	case 0x00040151:	func = GsU_00040151;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(PST|LMD|QUAD|IIP); */
//	case 0x00040154:	func = GsU_00040154;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT)|PRIM_TYPE(PST|LMD|QUAD|IIP|TME); */
//	case 0x00040155:	func = GsU_00040155;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT|DIV)|PRIM_TYPE(LMD|TRI); */
//	case 0x00050048:	func = GsU_00050048;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT|DIV)|PRIM_TYPE(LMD|TRI|TME); */
//	case 0x00050049:	func = GsU_00050049;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT|DIV)|PRIM_TYPE(LMD|TRI|IIP); */
//	case 0x0005004c:	func = GsU_0005004c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT|DIV)|PRIM_TYPE(LMD|TRI|IIP|TME); */
//	case 0x0005004d:	func = GsU_0005004d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT|DIV)|PRIM_TYPE(LMD|QUAD); */
//	case 0x00050050:	func = GsU_00050050;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT|DIV)|PRIM_TYPE(LMD|QUAD|TME); */
//	case 0x00050051:	func = GsU_00050051;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT|DIV)|PRIM_TYPE(LMD|QUAD|IIP); */
//	case 0x00050054:	func = GsU_00050054;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(LGT|DIV)|PRIM_TYPE(LMD|QUAD|IIP|TME); */
//	case 0x00050055:	func = GsU_00050055;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV)|PRIM_TYPE(TRI); */
//	case 0x00080008:	func = GsU_00080008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV)|PRIM_TYPE(TRI|TME); */
	// case 0x00080009:	func = GsU_00080009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV)|PRIM_TYPE(TRI|IIP); */
	// case 0x0008000c:	func = GsU_0008000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV)|PRIM_TYPE(TRI|IIP|TME); */
	// case 0x0008000d:	func = GsU_0008000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV)|PRIM_TYPE(QUAD); */
	// case 0x00080010:	func = GsU_00080010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV)|PRIM_TYPE(QUAD|TME); */
	// case 0x00080011:	func = GsU_00080011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV)|PRIM_TYPE(QUAD|IIP); */
	// case 0x00080014:	func = GsU_00080014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV)|PRIM_TYPE(QUAD|IIP|TME); */
	// case 0x00080015:	func = GsU_00080015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|FOG)|PRIM_TYPE(TRI); */
	// case 0x000a0008:	func = GsU_000a0008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|FOG)|PRIM_TYPE(TRI|TME); */
	// case 0x000a0009:	func = GsU_000a0009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|FOG)|PRIM_TYPE(TRI|IIP); */
	// case 0x000a000c:	func = GsU_000a000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|FOG)|PRIM_TYPE(TRI|IIP|TME); */
	// case 0x000a000d:	func = GsU_000a000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|FOG)|PRIM_TYPE(QUAD); */
	// case 0x000a0010:	func = GsU_000a0010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|FOG)|PRIM_TYPE(QUAD|TME); */
	// case 0x000a0011:	func = GsU_000a0011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|FOG)|PRIM_TYPE(QUAD|IIP); */
	// case 0x000a0014:	func = GsU_000a0014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|FOG)|PRIM_TYPE(QUAD|IIP|TME); */
	// case 0x000a0015:	func = GsU_000a0015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|LGT)|PRIM_TYPE(LMD|TRI); */
	// case 0x000c0048:	func = GsU_000c0048;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|LGT)|PRIM_TYPE(LMD|TRI|TME); */
	// case 0x000c0049:	func = GsU_000c0049;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|LGT)|PRIM_TYPE(LMD|TRI|IIP); */
	// case 0x000c004c:	func = GsU_000c004c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|LGT)|PRIM_TYPE(LMD|TRI|IIP|TME); */
	// case 0x000c004d:	func = GsU_000c004d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|LGT)|PRIM_TYPE(LMD|QUAD); */
	// case 0x000c0050:	func = GsU_000c0050;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|LGT)|PRIM_TYPE(LMD|QUAD|TME); */
	// case 0x000c0051:	func = GsU_000c0051;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|LGT)|PRIM_TYPE(LMD|QUAD|IIP); */
	// case 0x000c0054:	func = GsU_000c0054;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(ADV|LGT)|PRIM_TYPE(LMD|QUAD|IIP|TME); */
	// case 0x000c0055:	func = GsU_000c0055;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(TRI); */
	// case 0x00100008:	func = GsU_00100008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(TRI|TME); */
	// case 0x00100009:	func = GsU_00100009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(TRI|COL); */
	// case 0x0010000a:	func = GsU_0010000a;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(TRI|COL|TME); */
	// case 0x0010000b:	func = GsU_0010000b;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(TRI|IIP); */
	// case 0x0010000c:	func = GsU_0010000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(TRI|IIP|TME); */
	// case 0x0010000d:	func = GsU_0010000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(TRI|IIP|COL); */
	// case 0x0010000e:	func = GsU_0010000e;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(TRI|IIP|COL|TME); */
	// case 0x0010000f:	func = GsU_0010000f;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(QUAD); */
	// case 0x00100010:	func = GsU_00100010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(QUAD|TME); */
//	case 0x00100011:	func = GsU_00100011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(QUAD|COL); */
//	case 0x00100012:	func = GsU_00100012;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(QUAD|COL|TME); */
//	case 0x00100013:	func = GsU_00100013;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(QUAD|IIP); */
//	case 0x00100014:	func = GsU_00100014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(QUAD|IIP|TME); */
//	case 0x00100015:	func = GsU_00100015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(QUAD|IIP|COL); */
//	case 0x00100016:	func = GsU_00100016;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT)|PRIM_TYPE(QUAD|IIP|COL|TME); */
//	case 0x00100017:	func = GsU_00100017;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT|LGT)|PRIM_TYPE(LMD|TRI); */
//	case 0x00140048:	func = GsU_00140048;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT|LGT)|PRIM_TYPE(LMD|TRI|TME); */
//	case 0x00140049:	func = GsU_00140049;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT|LGT)|PRIM_TYPE(LMD|TRI|IIP); */
//	case 0x0014004c:	func = GsU_0014004c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT|LGT)|PRIM_TYPE(LMD|TRI|IIP|TME); */
//	case 0x0014004d:	func = GsU_0014004d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT|LGT)|PRIM_TYPE(LMD|QUAD); */
//	case 0x00140050:	func = GsU_00140050;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT|LGT)|PRIM_TYPE(LMD|QUAD|TME); */
//	case 0x00140051:	func = GsU_00140051;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT|LGT)|PRIM_TYPE(LMD|QUAD|IIP); */
//	case 0x00140054:	func = GsU_00140054;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(BOT|LGT)|PRIM_TYPE(LMD|QUAD|IIP|TME); */
//	case 0x00140055:	func = GsU_00140055;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(TRI); */
//	case 0x00200008:	func = GsU_00200008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(TRI|TME); */
//	case 0x00200009:	func = GsU_00200009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(TRI|COL); */
//	case 0x0020000a:	func = GsU_0020000a;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(TRI|COL|TME); */
//	case 0x0020000b:	func = GsU_0020000b;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(TRI|IIP); */
//	case 0x0020000c:	func = GsU_0020000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(TRI|IIP|TME); */
//	case 0x0020000d:	func = GsU_0020000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(TRI|IIP|COL); */
//	case 0x0020000e:	func = GsU_0020000e;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(TRI|IIP|COL|TME); */
//	case 0x0020000f:	func = GsU_0020000f;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(QUAD); */
//	case 0x00200010:	func = GsU_00200010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(QUAD|TME); */
//	case 0x00200011:	func = GsU_00200011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(QUAD|COL); */
//	case 0x00200012:	func = GsU_00200012;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(QUAD|COL|TME); */
//	case 0x00200013:	func = GsU_00200013;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(QUAD|IIP); */
//	case 0x00200014:	func = GsU_00200014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(QUAD|IIP|TME); */
//	case 0x00200015:	func = GsU_00200015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(QUAD|IIP|COL); */
//	case 0x00200016:	func = GsU_00200016;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP)|PRIM_TYPE(QUAD|IIP|COL|TME); */
//	case 0x00200017:	func = GsU_00200017;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|LGT)|PRIM_TYPE(LMD|TRI); */
//	case 0x00240048:	func = GsU_00240048;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|LGT)|PRIM_TYPE(LMD|TRI|TME); */
      case 0x00240049:        func = GsU_00240049;    break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|LGT)|PRIM_TYPE(LMD|TRI|IIP); */
//	case 0x0024004c:	func = GsU_0024004c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|LGT)|PRIM_TYPE(LMD|TRI|IIP|TME); */
//	case 0x0024004d:	func = GsU_0024004d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|LGT)|PRIM_TYPE(LMD|QUAD); */
//	case 0x00240050:	func = GsU_00240050;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|LGT)|PRIM_TYPE(LMD|QUAD|TME); */
	case 0x00240051:	func = GsU_00240051;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|LGT)|PRIM_TYPE(LMD|QUAD|IIP); */
//	case 0x00240054:	func = GsU_00240054;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|LGT)|PRIM_TYPE(LMD|QUAD|IIP|TME); */
//	case 0x00240055:	func = GsU_00240055;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(TRI); */
//	case 0x00300008:	func = GsU_00300008;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(TRI|TME); */
//	case 0x00300009:	func = GsU_00300009;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(TRI|COL); */
//	case 0x0030000a:	func = GsU_0030000a;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(TRI|COL|TME); */
//	case 0x0030000b:	func = GsU_0030000b;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(TRI|IIP); */
//	case 0x0030000c:	func = GsU_0030000c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(TRI|IIP|TME); */
//	case 0x0030000d:	func = GsU_0030000d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(TRI|IIP|COL); */
//	case 0x0030000e:	func = GsU_0030000e;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(TRI|IIP|COL|TME); */
//	case 0x0030000f:	func = GsU_0030000f;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(QUAD); */
//	case 0x00300010:	func = GsU_00300010;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(QUAD|TME); */
//	case 0x00300011:	func = GsU_00300011;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(QUAD|COL); */
//	case 0x00300012:	func = GsU_00300012;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(QUAD|COL|TME); */
//	case 0x00300013:	func = GsU_00300013;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(QUAD|IIP); */
//	case 0x00300014:	func = GsU_00300014;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(QUAD|IIP|TME); */
//	case 0x00300015:	func = GsU_00300015;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(QUAD|IIP|COL); */
//	case 0x00300016:	func = GsU_00300016;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT)|PRIM_TYPE(QUAD|IIP|COL|TME); */
//	case 0x00300017:	func = GsU_00300017;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT|LGT)|PRIM_TYPE(LMD|TRI); */
//	case 0x00340048:	func = GsU_00340048;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT|LGT)|PRIM_TYPE(LMD|TRI|TME); */
//	case 0x00340049:	func = GsU_00340049;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT|LGT)|PRIM_TYPE(LMD|TRI|IIP); */
//	case 0x0034004c:	func = GsU_0034004c;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT|LGT)|PRIM_TYPE(LMD|TRI|IIP|TME); */
//	case 0x0034004d:	func = GsU_0034004d;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT|LGT)|PRIM_TYPE(LMD|QUAD); */
//	case 0x00340050:	func = GsU_00340050;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT|LGT)|PRIM_TYPE(LMD|QUAD|TME); */
//	case 0x00340051:	func = GsU_00340051;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT|LGT)|PRIM_TYPE(LMD|QUAD|IIP); */
//	case 0x00340054:	func = GsU_00340054;	break;
	/* DEV_ID(SCE)|CTG(CTG_POLY)|DRV(STP|BOT|LGT)|PRIM_TYPE(LMD|QUAD|IIP|TME); */
//	case 0x00340055:	func = GsU_00340055;	break;

	default:
		printf("unsupported POLYGON primitive 0x%08x.\n", type);
		exit(1);
	}

	return (u_long)func;
}
