/*
	"ot.c" - Sample Code

	Copyright (C) 1998  Sony Computer Entertainment Europe
	All rights Reserved
*/

	// This file contains the three functions for creating each of the
	// Ordering Tables - Reflection, Ground and Main.

#define _OT_

#include <sys/types.h>
#include <libetc.h>
#include <libgte.h>
#include <libgpu.h>
#include <libgs.h>
#include <libhmd.h>

#include "3d.h"
#include "main.h"
#include "display.h"
#include "water.h"
#include "pad.h"
#include "music/xmplayer.h"

//#define P_ANALYZER

#ifdef DEVKIT
//#define MESSAGES_ON
//#define ARTIST
#endif

#ifdef DEVKIT
#include <libsn.h>
#else
#include <libcd.h>
#endif

#define MAIN_DEMO FALSE
#define INTRO TRUE

extern char WLK_FORE_ANIM_RAW[],WALKBACK_ANIM_RAW[];
extern char BACKOFF_ANIM_RAW[];

// ===================================================================
// ====  R E F L E C T I O N   O T ===================================
// ===================================================================
void CreateOTforReflection(void) {
	GsRVIEW2 testView;
	MATRIX tempMatrix;

	bool reflectedTriceratopsOnFlag;
	int diff;

			// Move the camera to the 'reflected' position.
	ReflectionCamera.vx = -CameraRotate.vx;
	ReflectionCamera.vy = CameraRotate.vy;
	ReflectionCamera.vz = CameraRotate.vz;

	testView.vpx = TopView.vpx;
	testView.vpy = WATER_DIST_FROM_0_INT + (-TopView.vpy);
	testView.vpz = TopView.vpz;

	createWorldToScreenMatrix(&testView, REFLECTION_CAMERA);

	tempMatrix = GsIDMATRIX;
	if(introModeOn) {
		ReflectionCamera.vx = -1024; // Pointing straight up.
	} else {
		RotMatrixZ(2048,&tempMatrix);
		GsMulCoord2(&tempMatrix,&GsWSMATRIX);
		tempMatrix = GsIDMATRIX;
	}

		// Flip the X (yes, this is an inefficient way of doing it)
	tempMatrix.m[0][0] = -tempMatrix.m[0][0];
	GsMulCoord2(&tempMatrix,&GsWSMATRIX);

			// Calculate if the triceratops is visible. It is not visible
			// if the camera is roughly on the same side of the clearing as
			// the dinosaur.
	diff = ((4096 - CameraRotate.vy + 2048) & (4096-1)) - (triceratopsAngle  & (4096-1));
	if(diff < 0) diff = -diff;
	reflectedTriceratopsOnFlag = (diff > 800);
			//If the difference in angles between camera and ttops
			// is < 800, we don't draw

		// This sets the flag that the HMD drivers will look at to determine
		// whether to negate the winding order and attenuate the colours.
	reflectionMode = TRUE;
	ProcessTriceratopsReflectionHMD(reflectedTriceratopsOnFlag);
	ProcessHMDModel(&treeHMD,&reflectionOT[g_ScreenBufferNum]);

	birdTMD.rotate.vy += 8;
	birdTMD.rotate.vy &= 4096-1;
	DrawTMDModel(&birdTMD,&reflectionOT[g_ScreenBufferNum],REFLECTION_OT_LENGTH);

	reflectionMode = FALSE;
}

// ===================================================================
// ====  M A I N   O T ===============================================
// ===================================================================

void CreateOTforMainScene(void) {
	ProcessTriceratopsHMD();
}

// ===================================================================
// ====  G R O U N D   O T ===========================================
// ===================================================================

void CreateOTforGround(void) {
	createWorldToScreenMatrix(&TopView,NORMAL_CAMERA);

			// Draw the environment and the inner tree, which as a side effect
			// sets up the GTE for the water.
	ProcessEnvironmentHMDModels();
	RenderWater();
}
