/*
	"init.c" - Sample Code

	Copyright (C) 1998  Sony Computer Entertainment Europe
	All rights Reserved
*/

	// This file contains the functions which call any initialisation
	// and raw data loading.

#define _INIT_

#define TEXTURES_PATH "gfx\\textures.tim"
#define SOUNDS_PATH "music\\samples.raw"

#include <sys/types.h>
#include <libgte.h>
#include <libgpu.h>
#include <libgs.h>
#include <stdio.h>
#include <libhmd.h>
#include <rand.h>

#include "3d.h"
#include "main.h"
#include "display.h"
#include "water.h"
#include "pad.h"
#include "music/xmplayer.h"

//#define P_ANALYZER

#ifdef DEVKIT
//#define MESSAGES_ON
//#define ARTIST
#endif

#ifdef DEVKIT
#include <libsn.h>
#else
#include <libcd.h>
#endif

extern char
		TTOPS_RAW[],
		ENVIRO_RAW[],
		ENVIRONP_RAW[],
		TERRY_TMD_RAW[],
		WLK_FORE_RAW[],
		WALKBACK_RAW[],
		BACKOFF_RAW[],
		IN_TREE_RAW[],
		ALLTREES_RAW[];

// ===================================================================
// ===================================================================
// ===================================================================

void exitProgram(void) {
	stopController();
	fadeOut();		// Fade out, show the credits.
	shutdownSound();
	ResetCallback();
	ResetGraph(3);
}

// =====================================================================
// ==== L O A D   S R A M   V R A M ====================================
// =====================================================================

void load_SRAM_VRAM(void) {
	int fh;
#ifdef DEVKIT
	int len;
	if(PCinit() != 0) {
		printf("PCinit error! Exiting.\n");
		exit(1);
	}
			// SRAM
#ifdef P_ANALYZER
	fh = PCopen("D:\\temp\\dino\\samples.raw",0,0);
#else

#ifdef ARTIST
	fh = PCopen("C:\\dino\\samples.raw",0,0);
#else
	fh = PCopen(SOUNDS_PATH,0,0);
#endif
#endif
	if(fh == -1) {
		printf("PCopen error! Can't open music!\n");
		exit(1);
	}
	len = PClseek(fh,0,2);
	PClseek(fh,0,0);
	PCread(fh,(char *)DATA_LOAD_ADDR,len);
	PCclose(fh);
	loadSRAM();

			// VRAM
#ifdef P_ANALYZER
	fh = PCopen("D:\\temp\\dino\\textures.tim",0,0);
#else
#ifdef ARTIST
	fh = PCopen("c:\\dino\\textures.tim",0,0);
#else
	fh = PCopen(TEXTURES_PATH,0,0);
#endif
#endif
	if(fh == -1) {
		printf("PCopen error! Can't open graphics!\n");
		exit(1);
	}
	len = PClseek(fh,0,2);
	PClseek(fh,0,0);
	PCread(fh,(char *)DATA_LOAD_ADDR,len);
	PCclose(fh);
	loadTIM((u_long *)DATA_LOAD_ADDR, NULL, NULL, NULL, NULL);
#else
	char status[100];
	if(CDinit(0) != 1) {
		printf("CDinit error! Exiting.\n");
		exit(1);
	}
			// SRAM
	fh = CDReadFile("\\DINO\\SAMPLES.RAW;1",DATA_LOAD_ADDR,0);
	if(fh == 0) {
		printf("CDopen error! Can't open music!\n");
		exit(1);
	}
	if(CDReadSync(0,status) != 0) {
		printf("CDReadSync returned an error! (music)\n");
		exit(1);
	}
	loadSRAM();

			// VRAM
	fh = CDReadFile("\\DINO\\TEXTURES.TIM;1",DATA_LOAD_ADDR,0);
	if(fh == 0) {
		printf("CDopen error! Can't open graphics!\n");
		exit(1);
	}
	if(CDReadSync(0,status) != 0) {
		printf("CDReadSync returned an error! (graphics)\n");
		exit(1);
	}
	loadTIM((u_long *)DATA_LOAD_ADDR, NULL, NULL, NULL, NULL);
	CDReset(1);
#endif
	DrawSync(0);
}

// =====================================================================
// ==== I N I T I A L I S E   M O D E L S ==============================
// =====================================================================

void initialiseModels(void) {

	CameraShudder_UD = CameraShudder_LR = 0;
	currentState = STOPPED;
	desiredState = STOPPED;
	tailAnimFrame = 0;
	headMoveLeftRight = headMoveUpDown = 0;
	roarNumber = 1;

	initialiseHMD((u_long *)ENVIRO_RAW, &environmentHMD);
	initialiseHMD((u_long *)ENVIRONP_RAW, &environmentNPHMD);
	initialiseHMD((u_long *)IN_TREE_RAW, &innerTreeHMD);
	initialiseHMD((u_long *)TTOPS_RAW, &triceratopsHMD);
	initialiseHMD((u_long *)ALLTREES_RAW, &treeHMD);

	initAnimateHMD(WLK_FORE_RAW, FALSE);
	initAnimateHMD(WALKBACK_RAW, FALSE);
	initAnimateHMD(BACKOFF_RAW, TRUE);

	initialiseTMD((u_long *)TERRY_TMD_RAW,0,&birdTMD);
	birdTMD.position.vx = birdTMD.position.vz = 400;
	birdTMD.rotate.vy = 0;
	birdTMD.rotate.vy &= 4096-1;
}


void init(void) {
	ResetCallback();
	initSound();
	initialiseDisplay();

	load_SRAM_VRAM();

	initWater();

	initController();
	initMusic();

	initialise3D();
	initialiseModels();

	StompStatus = FALSE;
	BoredTimer = 200;

	CameraDistance = FURTHEST_CAMERA_DISTANCE;
	CameraAngle = 2048;
	CameraLookUpDownAngle = 0;
	CameraHeight = 0;

	introModeOn = TRUE;

	CameraRotate.vx = 0;
	CameraRotate.vy = 0;
	CameraRotate.vz = 0;

	ReflectionCamera.vx = 4096*3/4;
	ReflectionCamera.vy = 0;
	ReflectionCamera.vz = 0;

	initNewDraw();  // Draw nothing a couple of times to clear both buffers
	completeDraw();
	initNewDraw();
	completeDraw();

#ifdef MESSAGES_ON
	FntLoad(512, 256);
	SetDumpFnt(FntOpen(-SCREEN_WIDTH/2 + 16, -SCREEN_HEIGHT/2 + 16, SCREEN_WIDTH, 240, 0, 1024));
#endif
}
