	// Sound related functions

#define TRUE 1
#define FALSE 0

#include <sys/types.h>
#include <libgte.h>
#include <libgpu.h>
#include <libgs.h>
#include <libetc.h>
#include <libspu.h>

#include "xmplay.h"

#include "xmplayer.h"

	// XM module - i.e. the pattern data and the pattern order.
extern char MUSIC_RAW[];

#define MALLOC_MAX 128
static char spu_malloc_rec[SPU_MALLOC_RECSIZ * (MALLOC_MAX + 1)];

/**** FEEDBACK STRUCTURES ****/

static XM_Feedback Feedback;
static XM_VABInfo VInfo;

static int VABID[8];
static int Song_ID1 =-1;

static int EruptVol=0, EruptStat=VOLUME_OFF;

// ==================================================================
// ==== PLAY SONG/SFX ===============================================
// ==================================================================

int PlaySong(int SongID,int FirstCh,int BitMask,int Offset) {

	int ID;
	ID=XM_Init
		(VABID[0],		/* VAB ID returned from XM_VABInit */
		0,				/* XM ID */
		SongID,			/* Song ID (-1 = allocate next available) */
		FirstCh,		/* First Channel */
		XM_Loop,		/* Looping? */
		BitMask,		/* Play bitmask */
		XM_Music,		/* Music or SFX?*/
		Offset);		/* Start offset or SFX Pattern */
	return(ID);
}



int PlayDSFX(int SFXID,int FirstCh,int BitMask,int Pattern) {
	int ID;
	ID=XM_Init
		(VABID[0],		/* VAB ID returned from XM_VABInit */
		0,				/* XM ID */
		SFXID,			/* Song ID (-1 = allocate next available) */
		FirstCh,		/* First Channel */
		XM_Loop,		/* Looping? */
		BitMask,		/* Play bitmask */
		XM_SFX,			/* Music or SFX?*/
		Pattern);		/* Start offset or SFX Pattern */
	return(ID);
}

// ==================================================================
// ==== INIT SOUND ==================================================
// ==================================================================

void initSound(void) {		// Before load
	long rev_mode;
	SpuReverbAttr r_attr;

	SpuInit();
	SpuSetCommonMasterVolume(0x3fff,0x3fff);
	SpuInitMalloc (MALLOC_MAX, spu_malloc_rec);

		// Modplayer specific stuff
#ifdef DISPLAY_PAL
	XM_OnceOffInit(XM_PAL);
#else
	XM_OnceOffInit(XM_NTSC);
#endif
}

	// This function will load the VB data at the address DATA_LOAD_ADDR into
	// SRAM.

void loadSRAM() {
		// The data at DATA_LOAD_ADDR is the VH data, which is duplicated
		// by the XM_VABInit function so we can throw it away afterwards.
		// The data at address DATA_LOAD_ADDR+3104 is the VB data that is
		// loaded into SPU RAM. This is performed by XM_VABInit as well.
		// After calling this function, we can discard the VH/VB data from
		// main memory.
	VABID[0]=XM_VABInit((char *)(DATA_LOAD_ADDR),
						(char *)(DATA_LOAD_ADDR + 3104)); // Load in music data

		// Wait for the SPU transfer to complete, because we're about to
		// overwrite that area with the graphics data.
	SpuIsTransferCompleted(SPU_TRANSFER_WAIT);
}

// ==================================================================
// ==== INIT MUSIC ==================================================
// ==================================================================

void initMusic(void) {
#define XM_ID_AMBIENCE 0
#define XM_ID_ERUPT 1
#define XM_ID_STOMP 3
#define XM_ID_ROAR1 2
#define XM_ID_ROAR2 2

	EruptVol=0;
	EruptStat=VOLUME_OFF;

		// MUSIC_RAW is the pattern and pattern list data (i.e, the XM without
		// the samples).
	InitXMData(MUSIC_RAW,0,XM_UseXMPanning);

			// The ambience track is the birds twittering and the crickets
			// squeaking. The eruption track is just a constant rumble
			// which we fade up and down.
	PlaySong(XM_ID_AMBIENCE,0,7,0);
	PlaySong(XM_ID_ERUPT   ,3,3,6);
	XM_SetMasterVol(XM_ID_ERUPT,0);
}

// =====================================================================
// =====================================================================
// =====================================================================

void pauseSong(int ID) {
	XM_Pause(ID);
}

// =====================================================================
// =====================================================================
// =====================================================================

void restartSong(int ID) {
	XM_Restart(ID);
}

// ==================================================================
// ==== SHUTDOWN SOUND ==============================================
// ==================================================================

void shutdownSound(void) {
	XM_Exit();
}

// ==================================================================
// ==== SOUND EFFECTS ===============================================
// ==================================================================

static int doARoar = 0;			// Flag - should we start a roar sound?
static int doAStomp = FALSE;	// Flag - should we start a stomp sound?

void doRoarSound(void) {
	doARoar = TRUE;
}

void doStompSound(void) {
	doAStomp = TRUE;
}

// ============================

void doEruptionSound(int action) {
	if(action == VOLUME_UP) {
		EruptStat=VOLUME_UP;
	} else if(action == VOLUME_DN) {
		EruptStat=VOLUME_DN;
	}
}

void processSounds(void) {

	static int stompChannelOffset = 0;
	static int roarType = 0;

		// ==== Set off a roar sound if necessary. There are two types
		// of roar, so we alternate between them.

	if(doARoar) {
		if(roarType) {
			PlayDSFX(XM_ID_ROAR1,5,1,4);
		} else {
			PlayDSFX(XM_ID_ROAR2,5,1,5);
		}
		roarType ^= 1;
		doARoar = FALSE;
	}

		// ==== Set off a stomp sound
		// Because the dinosaur can stomp quite fast, it is possible for
		// the sound of one stomp to overlap the sound of the next stomp.
		// If we played the stomp in the same channel all the time, this
		// would mean the old stomp would be abruptly cut off as the new
		// one started in the same channel. To get around this, we cycle
		// the 'stomp' sound between 4 channels.

	if(doAStomp) {
		stompChannelOffset++;
		if(stompChannelOffset == 4) {
			stompChannelOffset = 0;
		}

		PlayDSFX(XM_ID_STOMP+stompChannelOffset,
				 6+stompChannelOffset,
				 1,
				 3);
		doAStomp = FALSE;
	}

		// ==== Change the volume of the volcano eruption if necessary.

	if((EruptStat==VOLUME_DN) && (EruptVol!=0)) {
		EruptVol--;
	} else if((EruptStat==VOLUME_UP) && (EruptVol!=256)) {
		EruptVol++;
	} else {
		EruptStat=VOLUME_OFF;
	}

	if (EruptStat!=VOLUME_OFF) {
		XM_SetMasterVol(XM_ID_ERUPT,EruptVol/4);
	}

}